@@ -45,7 +45,7 @@ ARCHIVE_FILENAME_URI = re.sub(r'[:/.]+', '_', ARCHIVE_URI)
 ARCHIVE_FILENAME = f'archive_uri-{ARCHIVE_FILENAME_URI}-{CODENAME}.list'
 
 PPA_NAME = 'ubuntu-support-team/software-properties-autopkgtest'
-PPA_URI = f'http://ppa.launchpad.net/{PPA_NAME}/ubuntu/'
+PPA_URI = f'https://ppa.launchpadcontent.net/{PPA_NAME}/ubuntu/'
 PPA_FILENAME = f'ubuntu-support-team-ubuntu-software-properties-autopkgtest-{CODENAME}.list'
 PPA_TRUSTED_FILENAME = 'ubuntu-support-team-ubuntu-software-properties-autopkgtest.gpg'
 PPA_TRUSTED_FINGERPRINT = 'A17A D76F CBB7 A7D5 73C4  DF43 1E03 2FCE 2F88 6048'
